tlslite.errors.TLSAlert

Package tlslite :: Module errors :: Class TLSAlert |
[hide private]
[frames] | no frames]

# Class TLSAlert

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            TLSError --+
                                       |
                                      TLSAlert

Known Subclasses:
  - TLSLocalAlert
  - , TLSRemoteAlert

A TLS alert has been signalled.

Instance Methods | [hide private]
Inherited from `TLSError`: `__str__` Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _descriptionStr = ``{`0`:` `'``close_notify``'``,` 10`:` `'``unexpected_message``'``...``

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _descriptionStr Value:
      {0: 'close_notify',
       10: 'unexpected_message',
       20: 'bad_record_mac',
       21: 'decryption_failed',
       22: 'record_overflow',
       30: 'decompression_failure',
       40: 'handshake_failure',
       41: 'no certificate',
      ...